@@ -1,6 +1,6 @@
 ##----------------------------------------------------------------------------
 ## DateTime Format Relative Time - ~/lib/DateTime/Format/RelativeTime.pm
-## Version v0.1.1
+## Version v0.1.2
 ## Copyright(c) 2025 DEGUEST Pte. Ltd.
 ## Author: Jacques Deguest <jack@deguest.jp>
 ## Created 2024/12/30
@@ -27,7 +27,7 @@ BEGIN
     use Locale::Unicode::Data v1.3.0;
     use Scalar::Util ();
     use Want;
-    our $VERSION = 'v0.1.1';
+    our $VERSION = 'v0.1.2';
 };
 
 use strict;
@@ -678,7 +678,7 @@ sub _format_to_parts
             $self->_message( 4, "Value's integer part is '", ( $int // 'undef' ), "', and fraction part is '", ( $fraction // 'undef' ), "'" );
             push( @$parts, {
                 type => 'integer',
-                value => $digits->[ $int ],
+                value => join( '', map( $digits->[ $_ ], split( //, $int ) ) ),
                 unit => $unit,
             });
             if( defined( $fraction ) && length( $fraction ) )
@@ -1126,7 +1126,7 @@ For users requiring exact decimal representation beyond this precision, consider
 
 =head1 VERSION
 
-    v0.1.1
+    v0.1.2
 
 =head1 DESCRIPTION
 
